pub fn load(path: &Path) -> Result<LoadedConfig, ConfigError>Expand description
Read and parse path into the VELESDB_MEMORY_* variables it defines.
Errors
Returns ConfigError if the file cannot be read or is not valid TOML.
pub fn load(path: &Path) -> Result<LoadedConfig, ConfigError>Read and parse path into the VELESDB_MEMORY_* variables it defines.
Returns ConfigError if the file cannot be read or is not valid TOML.